yakumo.neutron.v2.lb.vip

Package yakumo :: Package neutron :: Package v2 :: Package lb :: Module vip |
[hide private]
[frames] | no frames]

# Module vip

source code

Resource class and its manager for LB virtual IPs in Networking V2 API

Classes | [hide private]
| Resource Resource class for LB virtual IPs in Networking V2 API
| Manager Manager class for LB virtual IPs in Networking V2 API

Variables | [hide private]
| ATTRIBUTE_MAPPING = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass obj`...``
| __package__ = ``'``yakumo.neutron.v2.lb``'``

Variables Details | [hide private]

  ### ATTRIBUTE_MAPPING Value:
      [('id', 'id', mapper.Noop), ('name', 'name', mapper.Noop), ('descripti
      on', 'description', mapper.Noop), ('protocol', 'protocol', mapper.Noop
      ), ('address', 'address', mapper.Noop), ('protocol_port', 'protocol_po
      rt', mapper.Noop), ('connection_limit', 'connection_limit', mapper.Noo
      p), ('pool', 'pool_id', mapper.Resource('neutron.lb.pool')), ('subnet'
      , 'subnet_id', mapper.Resource('neutron.subnet')), ('project', 'tenant
      _id', mapper.Resource('project')), ('port', 'port_id', mapper.Resource
      ('neutron.port')), ('is_enabled', 'admin_state_up', mapper.Noop), ('is
      ...